from setuptools import setup, find_packages

setup(
    name='rohn',                    # Your package name
    version='0.1',                        # Version number
    packages=find_packages(),             # Automatically find packages
    install_requires=[],                  # List dependencies if any
    author='rohn',                   # Your name
    author_email='rohnthomas22@gmail.com',# Your email
    description='my package',
    url='https://github.com/rohnthomas/rohn', # Your project URL
)
